@@ -3,7 +3,7 @@
 
 # maybe this module should be broken up into multiple files, or maybe not ...
 
-UA = "diffengine/0.0.41 (+https://github.com/docnow/diffengine)"
+UA = "diffengine/0.0.42 (+https://github.com/docnow/diffengine)"
 
 import os
 import re
@@ -511,8 +511,10 @@ punctuation = dict.fromkeys(i for i in range(sys.maxunicode)
         if unicodedata.category(chr(i)).startswith('P'))
 
 def _fingerprint(s):
-    # bleach everything, remove all whitespace and punctuation to create a 
-    # psuedo fingerprint for the text for use during compararison
+    # make sure the string has been normalized, bleach everything, remove all 
+    # whitespace and punctuation to create a psuedo fingerprint for the text 
+    # for use during compararison
+    s = _normal(s)
     s = bleach.clean(s, tags=[], strip=True)
     s = re.sub(r'\s+', '', s, flags=re.MULTILINE)
     s = s.translate(punctuation)
